pub struct FlagsContext {
pub values: Annotated<Array<FlagsContextItem>>,
pub other: Object<Value>,
}Expand description
Flags context.
The flags context is a collection of flag evaluations performed during the lifetime of a process. The flags are submitted in the order they were evaluated to preserve the state transformations taking place in the application.
Fields
values: Annotated<Array<FlagsContextItem>>An list of flag evaluation results in the order they were evaluated.
other: Object<Value>Additional arbitrary fields for forwards compatibility.