pub struct SpanV2 {
pub trace_id: Annotated<TraceId>,
pub parent_span_id: Annotated<SpanId>,
pub span_id: Annotated<SpanId>,
pub name: Annotated<OperationType>,
pub status: Annotated<SpanV2Status>,
pub is_segment: Annotated<bool>,
pub start_timestamp: Annotated<Timestamp>,
pub end_timestamp: Annotated<Timestamp>,
pub links: Annotated<Array<SpanV2Link>>,
pub attributes: Annotated<Attributes>,
pub other: Object<Value>,
}Expand description
A version 2 (transactionless) span.
Fields
trace_id: Annotated<TraceId>The ID of the trace to which this span belongs.
parent_span_id: Annotated<SpanId>The ID of the span enclosing this span.
span_id: Annotated<SpanId>The Span ID.
name: Annotated<OperationType>Span type (see OperationType docs).
status: Annotated<SpanV2Status>The span’s status.
is_segment: Annotated<bool>Whether this span is the root span of a segment.
start_timestamp: Annotated<Timestamp>Timestamp when the span started.
end_timestamp: Annotated<Timestamp>Timestamp when the span was ended.
links: Annotated<Array<SpanV2Link>>Links from this span to other spans.
attributes: Annotated<Attributes>Arbitrary attributes on a span.
other: Object<Value>Additional arbitrary fields for forwards compatibility.