pub struct ThreadPoolInfoContext {
pub available_worker_threads: Annotated<u64>,
pub available_completion_port_threads: Annotated<u64>,
pub max_worker_threads: Annotated<u64>,
pub max_completion_port_threads: Annotated<u64>,
pub min_worker_threads: Annotated<u64>,
pub min_completion_port_threads: Annotated<u64>,
pub other: Object<Value>,
}Expand description
Thread pool info context.
Fields
available_worker_threads: Annotated<u64>Number of worker threads currently available in the thread pool. Worker threads are used for executing application code and handling CPU-bound tasks.
available_completion_port_threads: Annotated<u64>Number of completion port threads (also known as I/O completion port threads) currently available. These threads handle I/O operations and asynchronous callbacks.
max_worker_threads: Annotated<u64>Maximum number of worker threads the thread pool can have. This represents the upper limit for worker thread allocation.
max_completion_port_threads: Annotated<u64>Maximum number of completion port threads the thread pool can maintain. This sets the ceiling for I/O completion port thread allocation.
min_worker_threads: Annotated<u64>Minimum number of worker threads maintained by the thread pool. The thread pool will always keep at least this many worker threads active.
min_completion_port_threads: Annotated<u64>Minimum number of completion port threads maintained by the thread pool. This ensures a baseline number of threads are available for I/O operations.
other: Object<Value>Trait Implementations
Sourceimpl Clone for ThreadPoolInfoContext
impl Clone for ThreadPoolInfoContext
Sourcefn clone(&self) -> ThreadPoolInfoContext
fn clone(&self) -> ThreadPoolInfoContext
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ThreadPoolInfoContext
impl Debug for ThreadPoolInfoContext
Sourceimpl Default for ThreadPoolInfoContext
impl Default for ThreadPoolInfoContext
Sourcefn default() -> ThreadPoolInfoContext
fn default() -> ThreadPoolInfoContext
Sourceimpl DefaultContext for ThreadPoolInfoContext
impl DefaultContext for ThreadPoolInfoContext
Sourcefn default_key() -> &'static str
fn default_key() -> &'static str
Contexts.Sourcefn from_context(context: Context) -> Option<Self>
fn from_context(context: Context) -> Option<Self>
Sourcefn cast(context: &Context) -> Option<&Self>
fn cast(context: &Context) -> Option<&Self>
Sourcefn cast_mut(context: &mut Context) -> Option<&mut Self>
fn cast_mut(context: &mut Context) -> Option<&mut Self>
Sourcefn into_context(self) -> Context
fn into_context(self) -> Context
Sourceimpl Empty for ThreadPoolInfoContext
impl Empty for ThreadPoolInfoContext
Sourceimpl FromValue for ThreadPoolInfoContext
impl FromValue for ThreadPoolInfoContext
Sourceimpl IntoValue for ThreadPoolInfoContext
impl IntoValue for ThreadPoolInfoContext
Sourcefn into_value(self) -> Value
fn into_value(self) -> Value
Sourcefn serialize_payload<S>(
&self,
__serializer: S,
__behavior: SkipSerialization,
) -> Result<S::Ok, S::Error>where
Self: Sized,
S: Serializer,
fn serialize_payload<S>(
&self,
__serializer: S,
__behavior: SkipSerialization,
) -> Result<S::Ok, S::Error>where
Self: Sized,
S: Serializer,
Sourcefn extract_child_meta(&self) -> MetaMapwhere
Self: Sized,
fn extract_child_meta(&self) -> MetaMapwhere
Self: Sized,
Sourceimpl PartialEq for ThreadPoolInfoContext
impl PartialEq for ThreadPoolInfoContext
Sourcefn eq(&self, other: &ThreadPoolInfoContext) -> bool
fn eq(&self, other: &ThreadPoolInfoContext) -> bool
self and other values to be equal, and is used by ==.